as.party.e2tree: Convert an E2Tree Object to partykit Format

View source: R/coercion.R

as.party.e2treeR Documentation

Convert an E2Tree Object to partykit Format

Description

Coerces an e2tree object into a party object from the partykit package. This enables the use of partykit's infrastructure for printing, plotting, and predicting with the E2Tree model.

Usage

as.party.e2tree(x, ...)

Arguments

x

An e2tree object.

...

Additional arguments (ignored).

Value

A party object (from partykit).

See Also

as.rpart.e2tree for conversion to rpart format.

Examples


data(iris)
smp_size <- floor(0.75 * nrow(iris))
train_ind <- sample(seq_len(nrow(iris)), size = smp_size)
training <- iris[train_ind, ]

ensemble <- randomForest::randomForest(Species ~ ., data = training,
  importance = TRUE, proximity = TRUE)
D <- createDisMatrix(ensemble, data = training, label = "Species",
  parallel = list(active = FALSE, no_cores = 1))
setting <- list(impTotal = 0.1, maxDec = 0.01, n = 2, level = 5)
tree <- e2tree(Species ~ ., training, D, ensemble, setting)

if (requireNamespace("partykit", quietly = TRUE)) {
  party_obj <- partykit::as.party(tree)
  plot(party_obj)
}



e2tree documentation built on May 15, 2026, 5:06 p.m.