ensemble_backend: Identify the canonical class of a supported ensemble model

View source: R/aaa_utils.R

ensemble_backendR Documentation

Identify the canonical class of a supported ensemble model

Description

Returns one of "randomForest", "ranger", "xgb.Booster", "lgb.Booster", "gbm", "catboost.CatBoost" or "catboost.Model" (the same class used by the S3 adapter dispatch), or NA_character_ when no supported class is matched.

Usage

ensemble_backend(ensemble)

e2tree documentation built on May 15, 2026, 5:06 p.m.