| measures | R Documentation |
Extracts the data frame of validation measures from an eValidation object, including divergence and similarity metrics between the ensemble and E2Tree proximity matrices.
measures(x, ...)
## S3 method for class 'eValidation'
measures(x, ...)
x |
An eValidation object. |
... |
Additional arguments (ignored). |
A data frame with columns for method name, type, observed value, and (if permutation tests were performed) null distribution statistics and p-values.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.