| nodes | R Documentation |
Extracts the data frame describing the nodes of an E2Tree model, including split rules, predictions, and node statistics.
nodes(x, ...)
## S3 method for class 'e2tree'
nodes(x, terminal = FALSE, ...)
x |
An e2tree object. |
... |
Additional arguments (ignored). |
terminal |
Logical. If |
A data frame with one row per node.
data(iris)
smp_size <- floor(0.75 * nrow(iris))
train_ind <- sample(seq_len(nrow(iris)), size = smp_size)
training <- iris[train_ind, ]
ensemble <- randomForest::randomForest(Species ~ ., data = training,
importance = TRUE, proximity = TRUE)
D <- createDisMatrix(ensemble, data = training, label = "Species",
parallel = list(active = FALSE, no_cores = 1))
setting <- list(impTotal = 0.1, maxDec = 0.01, n = 2, level = 5)
tree <- e2tree(Species ~ ., training, D, ensemble, setting)
nodes(tree)
nodes(tree, terminal = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.