| proximity | R Documentation |
Extracts proximity matrices from an eValidation object. The ensemble proximity matrix is derived from the original ensemble model, while the E2Tree proximity matrix is estimated from the fitted E2Tree.
proximity(x, ...)
## S3 method for class 'eValidation'
proximity(x, type = c("both", "ensemble", "e2tree"), ...)
x |
An eValidation object. |
... |
Additional arguments (ignored). |
type |
Character string specifying which proximity matrix to extract.
One of |
A matrix (if type is "ensemble" or "e2tree")
or a list of two matrices (if type is "both").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.