| vimp | R Documentation |
Computes variable importance for an E2Tree model based on mean impurity decrease and (for classification) mean accuracy decrease.
vimp(fit, data, type = NULL)
fit |
An e2tree object. |
data |
A data frame containing the variables in the model. |
type |
Character string: |
A list containing:
A data frame with variable importance metrics.
A ggplot bar chart of Mean Impurity Decrease.
(Classification only) A ggplot bar chart of Mean Accuracy Decrease.
## Classification:
data(iris)
# Create training and validation set:
smp_size <- floor(0.75 * nrow(iris))
train_ind <- sample(seq_len(nrow(iris)), size = smp_size)
training <- iris[train_ind, ]
# Perform training:
ensemble <- randomForest::randomForest(Species ~ ., data=training,
importance=TRUE, proximity=TRUE)
D <- createDisMatrix(ensemble, data=training, label = "Species",
parallel = list(active=FALSE, no_cores = 1))
setting=list(impTotal=0.1, maxDec=0.01, n=2, level=5)
tree <- e2tree(Species ~ ., training, D, ensemble, setting)
vi <- vimp(tree, training)
vi$vimp
vi$g_imp
## Regression
data("mtcars")
# Create training and validation set:
smp_size <- floor(0.75 * nrow(mtcars))
train_ind <- sample(seq_len(nrow(mtcars)), size = smp_size)
training <- mtcars[train_ind, ]
# Perform training
ensemble = randomForest::randomForest(mpg ~ ., data=training, ntree=1000,
importance=TRUE, proximity=TRUE)
D = createDisMatrix(ensemble, data=training, label = "mpg",
parallel = list(active=FALSE, no_cores = 1))
setting=list(impTotal=0.1, maxDec=(1*10^-6), n=2, level=5)
tree <- e2tree(mpg ~ ., training, D, ensemble, setting)
vi <- vimp(tree, training)
vi$vimp
vi$g_imp
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.